@@ -7,11 +7,12 @@ from paypal.express import views
 urlpatterns = patterns('',
     # Views for normal flow that starts on the basket page
     url(r'^redirect/', views.RedirectView.as_view(), name='paypal-redirect'),
-    url(r'^preview/', views.SuccessResponseView.as_view(preview=True),
+    url(r'^preview/(?P<basket_id>\d+)/$',
+        views.SuccessResponseView.as_view(preview=True),
         name='paypal-success-response'),
-    url(r'^cancel/', views.CancelResponseView.as_view(),
+    url(r'^cancel/(?P<basket_id>\d+)/$', views.CancelResponseView.as_view(),
         name='paypal-cancel-response'),
-    url(r'^place-order/', views.SuccessResponseView.as_view(),
+    url(r'^place-order/(?P<basket_id>\d+)/$', views.SuccessResponseView.as_view(),
         name='paypal-place-order'),
     # Callback for getting shipping options for a specific basket
     url(r'^shipping-options/(?P<basket_id>\d+)/',
